
## CATO-CLI - mutation.policy.antiMalwareFileHash.removeRule:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.policy.antiMalwareFileHash.removeRule) for documentation on this operation.

### Usage for mutation.policy.antiMalwareFileHash.removeRule:

`catocli mutation policy antiMalwareFileHash removeRule -h`

`catocli mutation policy antiMalwareFileHash removeRule <json>`

`catocli mutation policy antiMalwareFileHash removeRule "$(cat < mutation.policy.antiMalwareFileHash.removeRule.json)"`

`catocli mutation policy antiMalwareFileHash removeRule '{"antiMalwareFileHashPolicyMutationInput":{"policyMutationRevisionInput":{"id":"id"}},"antiMalwareFileHashRemoveRuleInput":{"id":"id"}}'`

`catocli mutation policy antiMalwareFileHash removeRule -p '{
    "antiMalwareFileHashPolicyMutationInput": {
        "policyMutationRevisionInput": {
            "id": "id"
        }
    },
    "antiMalwareFileHashRemoveRuleInput": {
        "id": "id"
    }
}'`


#### Operation Arguments for mutation.policy.antiMalwareFileHash.removeRule ####

`accountId` [ID] - (required) N/A    
`antiMalwareFileHashPolicyMutationInput` [AntiMalwareFileHashPolicyMutationInput] - (required) N/A    
`antiMalwareFileHashRemoveRuleInput` [AntiMalwareFileHashRemoveRuleInput] - (required) N/A    
